==> libfonts-java_0.1.4.orig.tar.gz: libfonts-java-0.1.4.orig/source/org/jfree/fonts/truetype/mappings/IsoPlatformIdentifier.java <==
/**
 * ========================================
 * libLayout : a free Java font reading library
 * ========================================
 *
 * Project Info:  http://www.jfree.org/liblayout/
 * Project Lead:  Thomas Morgner;
 *
 * (C) Copyright 2005, by Object Refinery Limited and Contributors.
 *
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * ---------
 * IsoPlatformIdentifier.java
 * ---------
 *
 * Original Author:  Thomas Morgner;
 * Contributors: -;
 *
 * $Id: IsoPlatformIdentifier.java,v 1.2 2005/11/09 21:24:12 taqua Exp $
 *
 * Changes
 * -------------------------
 * 2005-11-07 : Initial version
 */
package org.jfree.fonts.truetype.mappings;

/**
 * Creation-Date: 07.11.2005, 15:27:14
 *
 * @author Thomas Morgner
 */
public class IsoPlatformIdentifier extends PlatformIdentifier
{
  public IsoPlatformIdentifier()
  {
    super(2);
  }

  public String getEncoding(int encodingId, int language)
  {
    if (encodingId == 0)
    {
      return "US_ASCII";
    }
    else if (encodingId == 1)
    {
      return "UTF-16";
    }
    return "ISO-8859-1";
  }
}

==> libfonts-java_0.3.3.orig.tar.gz: libfonts-java-0.3.3.orig/source/org/jfree/fonts/truetype/mappings/IsoPlatformIdentifier.java <==
/**
 * ===========================================
 * LibFonts : a free Java font reading library
 * ===========================================
 *
 * Project Info:  http://reporting.pentaho.org/libfonts/
 *
 * (C) Copyright 2006-2007, by Pentaho Corporation and Contributors.
 *
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 *
 * ------------
 * $Id: IsoPlatformIdentifier.java 3523 2007-10-16 11:03:09Z tmorgner $
 * ------------
 * (C) Copyright 2006-2007, by Pentaho Corporation.
 */
package org.jfree.fonts.truetype.mappings;

/**
 * Creation-Date: 07.11.2005, 15:27:14
 *
 * @author Thomas Morgner
 */
public class IsoPlatformIdentifier extends PlatformIdentifier
{
  public IsoPlatformIdentifier()
  {
    super(2);
  }

  public String getEncoding(final int encodingId, final int language)
  {
    if (encodingId == 0)
    {
      return "US_ASCII";
    }
    else if (encodingId == 1)
    {
      return "UTF-16";
    }
    return "ISO-8859-1";
  }
}
